@@ -201,11 +201,11 @@ class Manager(object):
                     vec.record(point_process, 
                                getattr(sec(0.5), varRef), 
                                time_interval_recording)
-                    logging.info( "Sec: %s has pp: %s" %(sec.name(), point_process))
+                    logger.debug( "Sec: %s has pp: %s" %(sec.name(), point_process))
                 else:
                     vec.record(getattr(sec(0.5), varRef), 
                                time_interval_recording)
-                    logging.info( "Sec: %s has not pp" %(sec.name()))
+                    logger.debug( "Sec: %s has not pp" %(sec.name()))
             else:
                 if point_process:
                     vec.record(point_process, 
@@ -215,7 +215,7 @@ class Manager(object):
                 
             
         except NameError:
-            logging.error( "The variable %s is not present in the section %s" \
+            logger.error( "The variable %s is not present in the section %s" \
             % (varRef, sec.name()))
         
         h.pop_section()
@@ -333,7 +333,7 @@ class Manager(object):
                     plt.plot(self.groups['t'], vec, 'o', label=key)
                 elif len(x) != len(vec):
                     plt.plot(vec, 'o', label=key)
-                    logging.warning("x and y mismatched. Is the %s wrapped in the right baseref? \
+                    logger.warning("x and y mismatched. Is the %s wrapped in the right baseref? \
                     Plotted vs it's it own length anyway." %key)
                 else:
                     plt.plot(x, vec, 'o', label=key)
@@ -379,19 +379,21 @@ class Manager(object):
         """Sanitize the neuroML """
         import re
         split = sec_name.split('.') # Getting rid of the Cell name
-        sec = ''
-        name = ''
+        sec_sanitezed = None
+        sec_to_sanitize = None
+        m = None
         if len(split) == 1:
-            sec = split[0]
+            sec_to_sanitize = split[0]
         elif len(split) == 2: 
-            name = split[1]
-            m = re.match ('(\w+)\[(\d+)\]', name)
-            if m:
-                sec = m.group(1) +'_'+ m.group(2)
-                
-            else:
-                sec = name
-        return sec
+            sec_to_sanitize = split[1]
+            
+        m = re.match ('(\w+)\[(\d+)\]', sec_to_sanitize)
+        if m:
+            sec_sanitezed = m.group(1) +'_'+ m.group(2)
+            
+        else:
+            sec_sanitezed = sec_to_sanitize
+        return sec_sanitezed
         
     def _save_geom(self, h5file_holder):
         """Store the NeuroML in the geometry table"""
@@ -410,7 +412,7 @@ class Manager(object):
             xml_data = f.read()
         geom_group = h5file_holder.createGroup('/', self.geometry_root)
         h5file_holder.createArray(geom_group, self.geometry_node_name, 
-                                  [xml_data])
+                                  xml_data)
         os.remove(tmp_file)
         
     
@@ -506,8 +508,16 @@ class Manager(object):
         h5f = tables.openFile(filename)
         node = "/%s/%s" %(self.geometry_root, self.geometry_node_name) 
         geom = h5f.getNode(node)
-        xml_data = geom[0]  # get the string.
         
+        # List check for legacy code
+        xml_data = None
+        geom_data = geom.read()
+        if isinstance(geom_data, list):
+            xml_data = geom_data[0]  # get the string.
+        else:
+            xml_data = geom_data # The node is directly a string
+        logger.debug(type (xml_data))
+        logger.debug("xml_data is a list: %s" %isinstance(xml_data, list))
         tmp_file = 'temp.xml'
         f = open(tmp_file, 'w')
         f.write(xml_data)
@@ -591,12 +601,13 @@ class Manager(object):
         """Create the 3 grid (X,Y,Z) uses to plot wireframe or surface 3D 
         
         :param: distance_dic - dictionary with sections' names as key and 
-        distance as a value
+                distance as a value
         :param: time - Time array
         :param: variable_dic - dictionary with sections' names as key and 
-        array as value
+                array as value
+        :rtype: tuple (X,Y,Z) numpy array
         
-        :rtype: tuple (X,Y,Z) numpy array"""
+        """
         # create a grid
         X_time, Y_distance = np.meshgrid(time, distance_dic.values())
         Z_variable = X_time*0
